"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class RedisInstanceXMaintenancePolicyXWeeklyMaintenanceWindowXStartTime(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOURS_FIELD_NUMBER: builtins.int
    MINUTES_FIELD_NUMBER: builtins.int
    NANOS_FIELD_NUMBER: builtins.int
    SECONDS_FIELD_NUMBER: builtins.int
    hours: builtins.float
    minutes: builtins.float
    nanos: builtins.float
    seconds: builtins.float
    def __init__(
        self,
        *,
        hours: builtins.float = ...,
        minutes: builtins.float = ...,
        nanos: builtins.float = ...,
        seconds: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["hours", b"hours", "minutes", b"minutes", "nanos", b"nanos", "seconds", b"seconds"]) -> None: ...

global___RedisInstanceXMaintenancePolicyXWeeklyMaintenanceWindowXStartTime = RedisInstanceXMaintenancePolicyXWeeklyMaintenanceWindowXStartTime

@typing_extensions.final
class RedisInstanceXMaintenancePolicyXWeeklyMaintenanceWindow(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DAY_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    day: builtins.str
    duration: builtins.str
    @property
    def start_time(self) -> global___RedisInstanceXMaintenancePolicyXWeeklyMaintenanceWindowXStartTime: ...
    def __init__(
        self,
        *,
        day: builtins.str = ...,
        duration: builtins.str = ...,
        start_time: global___RedisInstanceXMaintenancePolicyXWeeklyMaintenanceWindowXStartTime | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["start_time", b"start_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["day", b"day", "duration", b"duration", "start_time", b"start_time"]) -> None: ...

global___RedisInstanceXMaintenancePolicyXWeeklyMaintenanceWindow = RedisInstanceXMaintenancePolicyXWeeklyMaintenanceWindow

@typing_extensions.final
class RedisInstanceXMaintenancePolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_TIME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    WEEKLY_MAINTENANCE_WINDOW_FIELD_NUMBER: builtins.int
    create_time: builtins.str
    description: builtins.str
    update_time: builtins.str
    @property
    def weekly_maintenance_window(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RedisInstanceXMaintenancePolicyXWeeklyMaintenanceWindow]: ...
    def __init__(
        self,
        *,
        create_time: builtins.str = ...,
        description: builtins.str = ...,
        update_time: builtins.str = ...,
        weekly_maintenance_window: collections.abc.Iterable[global___RedisInstanceXMaintenancePolicyXWeeklyMaintenanceWindow] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create_time", b"create_time", "description", b"description", "update_time", b"update_time", "weekly_maintenance_window", b"weekly_maintenance_window"]) -> None: ...

global___RedisInstanceXMaintenancePolicy = RedisInstanceXMaintenancePolicy

@typing_extensions.final
class RedisInstanceXMaintenanceSchedule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    END_TIME_FIELD_NUMBER: builtins.int
    SCHEDULE_DEADLINE_TIME_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    end_time: builtins.str
    schedule_deadline_time: builtins.str
    start_time: builtins.str
    def __init__(
        self,
        *,
        end_time: builtins.str = ...,
        schedule_deadline_time: builtins.str = ...,
        start_time: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["end_time", b"end_time", "schedule_deadline_time", b"schedule_deadline_time", "start_time", b"start_time"]) -> None: ...

global___RedisInstanceXMaintenanceSchedule = RedisInstanceXMaintenanceSchedule

@typing_extensions.final
class RedisInstanceXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___RedisInstanceXTimeouts = RedisInstanceXTimeouts

@typing_extensions.final
class RedisInstance(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class NodesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class RedisConfigsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class ServerCaCertsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ALTERNATIVE_LOCATION_ID_FIELD_NUMBER: builtins.int
    AUTH_ENABLED_FIELD_NUMBER: builtins.int
    AUTH_STRING_FIELD_NUMBER: builtins.int
    AUTHORIZED_NETWORK_FIELD_NUMBER: builtins.int
    CONNECT_MODE_FIELD_NUMBER: builtins.int
    CREATE_TIME_FIELD_NUMBER: builtins.int
    CURRENT_LOCATION_ID_FIELD_NUMBER: builtins.int
    CUSTOMER_MANAGED_KEY_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    HOST_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    LOCATION_ID_FIELD_NUMBER: builtins.int
    MEMORY_SIZE_GB_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NODES_FIELD_NUMBER: builtins.int
    PERSISTENCE_IAM_IDENTITY_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    READ_ENDPOINT_FIELD_NUMBER: builtins.int
    READ_ENDPOINT_PORT_FIELD_NUMBER: builtins.int
    READ_REPLICAS_MODE_FIELD_NUMBER: builtins.int
    REDIS_CONFIGS_FIELD_NUMBER: builtins.int
    REDIS_VERSION_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    REPLICA_COUNT_FIELD_NUMBER: builtins.int
    RESERVED_IP_RANGE_FIELD_NUMBER: builtins.int
    SECONDARY_IP_RANGE_FIELD_NUMBER: builtins.int
    SERVER_CA_CERTS_FIELD_NUMBER: builtins.int
    TIER_FIELD_NUMBER: builtins.int
    TRANSIT_ENCRYPTION_MODE_FIELD_NUMBER: builtins.int
    MAINTENANCE_POLICY_FIELD_NUMBER: builtins.int
    MAINTENANCE_SCHEDULE_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    alternative_location_id: builtins.str
    auth_enabled: builtins.bool
    auth_string: builtins.str
    authorized_network: builtins.str
    connect_mode: builtins.str
    create_time: builtins.str
    current_location_id: builtins.str
    customer_managed_key: builtins.str
    display_name: builtins.str
    host: builtins.str
    id: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    location_id: builtins.str
    memory_size_gb: builtins.float
    name: builtins.str
    @property
    def nodes(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    persistence_iam_identity: builtins.str
    port: builtins.float
    project: builtins.str
    read_endpoint: builtins.str
    read_endpoint_port: builtins.float
    read_replicas_mode: builtins.str
    @property
    def redis_configs(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    redis_version: builtins.str
    region: builtins.str
    replica_count: builtins.float
    reserved_ip_range: builtins.str
    secondary_ip_range: builtins.str
    @property
    def server_ca_certs(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    tier: builtins.str
    transit_encryption_mode: builtins.str
    @property
    def maintenance_policy(self) -> global___RedisInstanceXMaintenancePolicy: ...
    @property
    def maintenance_schedule(self) -> global___RedisInstanceXMaintenanceSchedule: ...
    @property
    def timeouts(self) -> global___RedisInstanceXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        alternative_location_id: builtins.str = ...,
        auth_enabled: builtins.bool = ...,
        auth_string: builtins.str = ...,
        authorized_network: builtins.str = ...,
        connect_mode: builtins.str = ...,
        create_time: builtins.str = ...,
        current_location_id: builtins.str = ...,
        customer_managed_key: builtins.str = ...,
        display_name: builtins.str = ...,
        host: builtins.str = ...,
        id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        location_id: builtins.str = ...,
        memory_size_gb: builtins.float = ...,
        name: builtins.str = ...,
        nodes: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        persistence_iam_identity: builtins.str = ...,
        port: builtins.float = ...,
        project: builtins.str = ...,
        read_endpoint: builtins.str = ...,
        read_endpoint_port: builtins.float = ...,
        read_replicas_mode: builtins.str = ...,
        redis_configs: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        redis_version: builtins.str = ...,
        region: builtins.str = ...,
        replica_count: builtins.float = ...,
        reserved_ip_range: builtins.str = ...,
        secondary_ip_range: builtins.str = ...,
        server_ca_certs: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        tier: builtins.str = ...,
        transit_encryption_mode: builtins.str = ...,
        maintenance_policy: global___RedisInstanceXMaintenancePolicy | None = ...,
        maintenance_schedule: global___RedisInstanceXMaintenanceSchedule | None = ...,
        timeouts: global___RedisInstanceXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["maintenance_policy", b"maintenance_policy", "maintenance_schedule", b"maintenance_schedule", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["alternative_location_id", b"alternative_location_id", "auth_enabled", b"auth_enabled", "auth_string", b"auth_string", "authorized_network", b"authorized_network", "connect_mode", b"connect_mode", "create_time", b"create_time", "current_location_id", b"current_location_id", "customer_managed_key", b"customer_managed_key", "display_name", b"display_name", "host", b"host", "id", b"id", "labels", b"labels", "location_id", b"location_id", "maintenance_policy", b"maintenance_policy", "maintenance_schedule", b"maintenance_schedule", "memory_size_gb", b"memory_size_gb", "name", b"name", "nodes", b"nodes", "persistence_iam_identity", b"persistence_iam_identity", "port", b"port", "project", b"project", "read_endpoint", b"read_endpoint", "read_endpoint_port", b"read_endpoint_port", "read_replicas_mode", b"read_replicas_mode", "redis_configs", b"redis_configs", "redis_version", b"redis_version", "region", b"region", "replica_count", b"replica_count", "reserved_ip_range", b"reserved_ip_range", "resource_info", b"resource_info", "secondary_ip_range", b"secondary_ip_range", "server_ca_certs", b"server_ca_certs", "tier", b"tier", "timeouts", b"timeouts", "transit_encryption_mode", b"transit_encryption_mode"]) -> None: ...

global___RedisInstance = RedisInstance



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class FirebaserulesReleaseXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___FirebaserulesReleaseXTimeouts = FirebaserulesReleaseXTimeouts

@typing_extensions.final
class FirebaserulesRelease(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_TIME_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    RULESET_NAME_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    create_time: builtins.str
    disabled: builtins.bool
    id: builtins.str
    name: builtins.str
    project: builtins.str
    ruleset_name: builtins.str
    update_time: builtins.str
    @property
    def timeouts(self) -> global___FirebaserulesReleaseXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        create_time: builtins.str = ...,
        disabled: builtins.bool = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        ruleset_name: builtins.str = ...,
        update_time: builtins.str = ...,
        timeouts: global___FirebaserulesReleaseXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["create_time", b"create_time", "disabled", b"disabled", "id", b"id", "name", b"name", "project", b"project", "resource_info", b"resource_info", "ruleset_name", b"ruleset_name", "timeouts", b"timeouts", "update_time", b"update_time"]) -> None: ...

global___FirebaserulesRelease = FirebaserulesRelease

@typing_extensions.final
class FirebaserulesRulesetXSourceXFiles(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTENT_FIELD_NUMBER: builtins.int
    FINGERPRINT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    content: builtins.str
    fingerprint: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        content: builtins.str = ...,
        fingerprint: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "fingerprint", b"fingerprint", "name", b"name"]) -> None: ...

global___FirebaserulesRulesetXSourceXFiles = FirebaserulesRulesetXSourceXFiles

@typing_extensions.final
class FirebaserulesRulesetXSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LANGUAGE_FIELD_NUMBER: builtins.int
    FILES_FIELD_NUMBER: builtins.int
    language: builtins.str
    @property
    def files(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FirebaserulesRulesetXSourceXFiles]: ...
    def __init__(
        self,
        *,
        language: builtins.str = ...,
        files: collections.abc.Iterable[global___FirebaserulesRulesetXSourceXFiles] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["files", b"files", "language", b"language"]) -> None: ...

global___FirebaserulesRulesetXSource = FirebaserulesRulesetXSource

@typing_extensions.final
class FirebaserulesRulesetXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___FirebaserulesRulesetXTimeouts = FirebaserulesRulesetXTimeouts

@typing_extensions.final
class FirebaserulesRuleset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class MetadataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CREATE_TIME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    create_time: builtins.str
    id: builtins.str
    @property
    def metadata(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    project: builtins.str
    @property
    def source(self) -> global___FirebaserulesRulesetXSource: ...
    @property
    def timeouts(self) -> global___FirebaserulesRulesetXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        create_time: builtins.str = ...,
        id: builtins.str = ...,
        metadata: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        source: global___FirebaserulesRulesetXSource | None = ...,
        timeouts: global___FirebaserulesRulesetXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "source", b"source", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["create_time", b"create_time", "id", b"id", "metadata", b"metadata", "name", b"name", "project", b"project", "resource_info", b"resource_info", "source", b"source", "timeouts", b"timeouts"]) -> None: ...

global___FirebaserulesRuleset = FirebaserulesRuleset



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_sourcerepo.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18gcp/gcp_sourcerepo.proto\x12\x1aoak9.tython.gcp.sourcerepo\x1a\x13shared/shared.proto\"j\n\"SourcerepoRepositoryXPubsubConfigs\x12\x16\n\x0emessage_format\x18\x01 \x01(\t\x12\x1d\n\x15service_account_email\x18\x02 \x01(\t\x12\r\n\x05topic\x18\x03 \x01(\t\"O\n\x1dSourcerepoRepositoryXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xba\x02\n\x14SourcerepoRepository\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07project\x18\x03 \x01(\t\x12\x0c\n\x04size\x18\x04 \x01(\x01\x12\x0b\n\x03url\x18\x05 \x01(\t\x12V\n\x0epubsub_configs\x18\x06 \x03(\x0b\x32>.oak9.tython.gcp.sourcerepo.SourcerepoRepositoryXPubsubConfigs\x12K\n\x08timeouts\x18\x07 \x01(\x0b\x32\x39.oak9.tython.gcp.sourcerepo.SourcerepoRepositoryXTimeouts\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"b\n(SourcerepoRepositoryIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x90\x02\n\x1eSourcerepoRepositoryIamBinding\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07members\x18\x03 \x03(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\x12\n\nrepository\x18\x05 \x01(\t\x12\x0c\n\x04role\x18\x06 \x01(\t\x12W\n\tcondition\x18\x07 \x01(\x0b\x32\x44.oak9.tython.gcp.sourcerepo.SourcerepoRepositoryIamBindingXCondition\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"a\n\'SourcerepoRepositoryIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x8d\x02\n\x1dSourcerepoRepositoryIamMember\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0e\n\x06member\x18\x03 \x01(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\x12\n\nrepository\x18\x05 \x01(\t\x12\x0c\n\x04role\x18\x06 \x01(\t\x12V\n\tcondition\x18\x07 \x01(\x0b\x32\x43.oak9.tython.gcp.sourcerepo.SourcerepoRepositoryIamMemberXCondition\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xac\x01\n\x1dSourcerepoRepositoryIamPolicy\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x03 \x01(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\x12\n\nrepository\x18\x05 \x01(\t\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_sourcerepo_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SOURCEREPOREPOSITORYXPUBSUBCONFIGS._serialized_start=77
  _SOURCEREPOREPOSITORYXPUBSUBCONFIGS._serialized_end=183
  _SOURCEREPOREPOSITORYXTIMEOUTS._serialized_start=185
  _SOURCEREPOREPOSITORYXTIMEOUTS._serialized_end=264
  _SOURCEREPOREPOSITORY._serialized_start=267
  _SOURCEREPOREPOSITORY._serialized_end=581
  _SOURCEREPOREPOSITORYIAMBINDINGXCONDITION._serialized_start=583
  _SOURCEREPOREPOSITORYIAMBINDINGXCONDITION._serialized_end=681
  _SOURCEREPOREPOSITORYIAMBINDING._serialized_start=684
  _SOURCEREPOREPOSITORYIAMBINDING._serialized_end=956
  _SOURCEREPOREPOSITORYIAMMEMBERXCONDITION._serialized_start=958
  _SOURCEREPOREPOSITORYIAMMEMBERXCONDITION._serialized_end=1055
  _SOURCEREPOREPOSITORYIAMMEMBER._serialized_start=1058
  _SOURCEREPOREPOSITORYIAMMEMBER._serialized_end=1327
  _SOURCEREPOREPOSITORYIAMPOLICY._serialized_start=1330
  _SOURCEREPOREPOSITORYIAMPOLICY._serialized_end=1502
# @@protoc_insertion_point(module_scope)



from models.shared.shared_pb2 import Graph
from core.sdk.resource_map import grpc_type_map
import core.sdk.helper as Helper

class GraphHelper:
    '''
    Provides functions to handle graph data
    '''
    
    
    def filter_by_resource(graph: Graph, resource):
        filtered_resource = []

        for root_node in graph.root_nodes:
            mapped = grpc_type_map.get(root_node.node.resource.data.type_url)
            if mapped == resource:
                # parse and add to the list
                filtered_resource.append(Helper.unpack_grpc_resource(root_node.node.resource.data, mapped))

        return filtered_resource



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_vertex.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14gcp/gcp_vertex.proto\x12\x16oak9.tython.gcp.vertex\x1a\x13shared/shared.proto\"6\n\x1eVertexAiDatasetXEncryptionSpec\x12\x14\n\x0ckms_key_name\x18\x01 \x01(\t\"J\n\x18VertexAiDatasetXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xeb\x03\n\x0fVertexAiDataset\x12\x13\n\x0b\x63reate_time\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x43\n\x06labels\x18\x04 \x03(\x0b\x32\x33.oak9.tython.gcp.vertex.VertexAiDataset.LabelsEntry\x12\x1b\n\x13metadata_schema_uri\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0f\n\x07project\x18\x07 \x01(\t\x12\x0e\n\x06region\x18\x08 \x01(\t\x12\x13\n\x0bupdate_time\x18\t \x01(\t\x12O\n\x0f\x65ncryption_spec\x18\n \x01(\x0b\x32\x36.oak9.tython.gcp.vertex.VertexAiDatasetXEncryptionSpec\x12\x42\n\x08timeouts\x18\x0b \x01(\x0b\x32\x30.oak9.tython.gcp.vertex.VertexAiDatasetXTimeouts\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_vertex_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _VERTEXAIDATASET_LABELSENTRY._options = None
  _VERTEXAIDATASET_LABELSENTRY._serialized_options = b'8\001'
  _VERTEXAIDATASETXENCRYPTIONSPEC._serialized_start=69
  _VERTEXAIDATASETXENCRYPTIONSPEC._serialized_end=123
  _VERTEXAIDATASETXTIMEOUTS._serialized_start=125
  _VERTEXAIDATASETXTIMEOUTS._serialized_end=199
  _VERTEXAIDATASET._serialized_start=202
  _VERTEXAIDATASET._serialized_end=693
  _VERTEXAIDATASET_LABELSENTRY._serialized_start=648
  _VERTEXAIDATASET_LABELSENTRY._serialized_end=693
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_kinesisfirehose.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x61ws/aws_kinesisfirehose.proto\x12\x1foak9.tython.aws.kinesisfirehose\x1a\x13shared/shared.proto\"\x96\x01\n)DeliveryStreamElasticsearchBufferingHints\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13interval_in_seconds\x18\x02 \x01(\x05\x12\x13\n\x0bsize_in_mbs\x18\x03 \x01(\x05\"\xa3\x01\n&DeliveryStreamCloudWatchLoggingOptions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12\x16\n\x0elog_group_name\x18\x03 \x01(\t\x12\x17\n\x0flog_stream_name\x18\x04 \x01(\t\"\x8c\x01\n DeliveryStreamProcessorParameter\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0eparameter_name\x18\x02 \x01(\t\x12\x17\n\x0fparameter_value\x18\x03 \x01(\t\"\xa9\x01\n\x17\x44\x65liveryStreamProcessor\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12U\n\nparameters\x18\x02 \x03(\x0b\x32\x41.oak9.tython.aws.kinesisfirehose.DeliveryStreamProcessorParameter\"\xbf\x01\n%DeliveryStreamProcessingConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12L\n\nprocessors\x18\x03 \x03(\x0b\x32\x38.oak9.tython.aws.kinesisfirehose.DeliveryStreamProcessor\"\x7f\n\'DeliveryStreamElasticsearchRetryOptions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13\x64uration_in_seconds\x18\x02 \x01(\x05\"\x89\x01\n\x1c\x44\x65liveryStreamBufferingHints\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13interval_in_seconds\x18\x02 \x01(\x05\x12\x13\n\x0bsize_in_mbs\x18\x03 \x01(\x05\"u\n!DeliveryStreamKMSEncryptionConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0f\x61ws_kms_key_arn\x18\x02 \x01(\t\"\xe1\x01\n%DeliveryStreamEncryptionConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x61\n\x15kms_encryption_config\x18\x02 \x01(\x0b\x32\x42.oak9.tython.aws.kinesisfirehose.DeliveryStreamKMSEncryptionConfig\x12\x1c\n\x14no_encryption_config\x18\x03 \x01(\t\"\x82\x04\n(DeliveryStreamS3DestinationConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nbucket_arn\x18\x02 \x01(\t\x12V\n\x0f\x62uffering_hints\x18\x03 \x01(\x0b\x32=.oak9.tython.aws.kinesisfirehose.DeliveryStreamBufferingHints\x12l\n\x1b\x63loud_watch_logging_options\x18\x04 \x01(\x0b\x32G.oak9.tython.aws.kinesisfirehose.DeliveryStreamCloudWatchLoggingOptions\x12\x1a\n\x12\x63ompression_format\x18\x05 \x01(\t\x12h\n\x18\x65ncryption_configuration\x18\x06 \x01(\x0b\x32\x46.oak9.tython.aws.kinesisfirehose.DeliveryStreamEncryptionConfiguration\x12\x1b\n\x13\x65rror_output_prefix\x18\x07 \x01(\t\x12\x0e\n\x06prefix\x18\x08 \x01(\t\x12\x10\n\x08role_arn\x18\t \x01(\t\"\x9b\x01\n\x1e\x44\x65liveryStreamVpcConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08role_arn\x18\x02 \x01(\t\x12\x12\n\nsubnet_ids\x18\x03 \x03(\t\x12\x1a\n\x12security_group_ids\x18\x04 \x03(\t\"\xeb\x06\n3DeliveryStreamElasticsearchDestinationConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x63\n\x0f\x62uffering_hints\x18\x02 \x01(\x0b\x32J.oak9.tython.aws.kinesisfirehose.DeliveryStreamElasticsearchBufferingHints\x12l\n\x1b\x63loud_watch_logging_options\x18\x03 \x01(\x0b\x32G.oak9.tython.aws.kinesisfirehose.DeliveryStreamCloudWatchLoggingOptions\x12\x12\n\ndomain_arn\x18\x04 \x01(\t\x12\x12\n\nindex_name\x18\x05 \x01(\t\x12\x1d\n\x15index_rotation_period\x18\x06 \x01(\t\x12h\n\x18processing_configuration\x18\x07 \x01(\x0b\x32\x46.oak9.tython.aws.kinesisfirehose.DeliveryStreamProcessingConfiguration\x12_\n\rretry_options\x18\x08 \x01(\x0b\x32H.oak9.tython.aws.kinesisfirehose.DeliveryStreamElasticsearchRetryOptions\x12\x10\n\x08role_arn\x18\t \x01(\t\x12\x16\n\x0es3_backup_mode\x18\n \x01(\t\x12\x63\n\x10s3_configuration\x18\x0b \x01(\x0b\x32I.oak9.tython.aws.kinesisfirehose.DeliveryStreamS3DestinationConfiguration\x12\x18\n\x10\x63luster_endpoint\x18\x0c \x01(\t\x12\x11\n\ttype_name\x18\r \x01(\t\x12Z\n\x11vpc_configuration\x18\x0e \x01(\x0b\x32?.oak9.tython.aws.kinesisfirehose.DeliveryStreamVpcConfiguration\"q\n\x1b\x44\x65liveryStreamHiveJsonSerDe\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11timestamp_formats\x18\x02 \x03(\t\"\xe4\x02\n\x1c\x44\x65liveryStreamOpenXJsonSerDe\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x63\x61se_insensitive\x18\x02 \x01(\x08\x12\x7f\n\x1b\x63olumn_to_json_key_mappings\x18\x03 \x03(\x0b\x32Z.oak9.tython.aws.kinesisfirehose.DeliveryStreamOpenXJsonSerDe.ColumnToJsonKeyMappingsEntry\x12\x30\n(convert_dots_in_json_keys_to_underscores\x18\x04 \x01(\x08\x1a>\n\x1c\x43olumnToJsonKeyMappingsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x88\x02\n\x1a\x44\x65liveryStreamDeserializer\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12V\n\x10hive_json_ser_de\x18\x02 \x01(\x0b\x32<.oak9.tython.aws.kinesisfirehose.DeliveryStreamHiveJsonSerDe\x12Y\n\x12open_x_json_ser_de\x18\x03 \x01(\x0b\x32=.oak9.tython.aws.kinesisfirehose.DeliveryStreamOpenXJsonSerDe\"\xb4\x01\n&DeliveryStreamInputFormatConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12Q\n\x0c\x64\x65serializer\x18\x02 \x01(\x0b\x32;.oak9.tython.aws.kinesisfirehose.DeliveryStreamDeserializer\"\xf1\x02\n\x16\x44\x65liveryStreamOrcSerDe\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x62lock_size_bytes\x18\x02 \x01(\x05\x12\x1c\n\x14\x62loom_filter_columns\x18\x03 \x03(\t\x12/\n\'bloom_filter_false_positive_probability\x18\x04 \x01(\x01\x12\x13\n\x0b\x63ompression\x18\x05 \x01(\t\x12 \n\x18\x64ictionary_key_threshold\x18\x06 \x01(\x01\x12\x16\n\x0e\x65nable_padding\x18\x07 \x01(\x08\x12\x16\n\x0e\x66ormat_version\x18\x08 \x01(\t\x12\x19\n\x11padding_tolerance\x18\t \x01(\x01\x12\x18\n\x10row_index_stride\x18\n \x01(\x05\x12\x19\n\x11stripe_size_bytes\x18\x0b \x01(\x05\"\xf7\x01\n\x1a\x44\x65liveryStreamParquetSerDe\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x62lock_size_bytes\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ompression\x18\x03 \x01(\t\x12%\n\x1d\x65nable_dictionary_compression\x18\x04 \x01(\x08\x12\x19\n\x11max_padding_bytes\x18\x05 \x01(\x05\x12\x17\n\x0fpage_size_bytes\x18\x06 \x01(\x05\x12\x16\n\x0ewriter_version\x18\x07 \x01(\t\"\xf5\x01\n\x18\x44\x65liveryStreamSerializer\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12K\n\norc_ser_de\x18\x02 \x01(\x0b\x32\x37.oak9.tython.aws.kinesisfirehose.DeliveryStreamOrcSerDe\x12S\n\x0eparquet_ser_de\x18\x03 \x01(\x0b\x32;.oak9.tython.aws.kinesisfirehose.DeliveryStreamParquetSerDe\"\xb1\x01\n\'DeliveryStreamOutputFormatConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12M\n\nserializer\x18\x02 \x01(\x0b\x32\x39.oak9.tython.aws.kinesisfirehose.DeliveryStreamSerializer\"\xd1\x01\n!DeliveryStreamSchemaConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\ncatalog_id\x18\x02 \x01(\t\x12\x15\n\rdatabase_name\x18\x03 \x01(\t\x12\x0e\n\x06region\x18\x04 \x01(\t\x12\x10\n\x08role_arn\x18\x05 \x01(\t\x12\x12\n\ntable_name\x18\x06 \x01(\t\x12\x12\n\nversion_id\x18\x07 \x01(\t\"\xb9\x03\n/DeliveryStreamDataFormatConversionConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12k\n\x1ainput_format_configuration\x18\x03 \x01(\x0b\x32G.oak9.tython.aws.kinesisfirehose.DeliveryStreamInputFormatConfiguration\x12m\n\x1boutput_format_configuration\x18\x04 \x01(\x0b\x32H.oak9.tython.aws.kinesisfirehose.DeliveryStreamOutputFormatConfiguration\x12`\n\x14schema_configuration\x18\x05 \x01(\x0b\x32\x42.oak9.tython.aws.kinesisfirehose.DeliveryStreamSchemaConfiguration\"\xf8\x06\n0DeliveryStreamExtendedS3DestinationConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nbucket_arn\x18\x02 \x01(\t\x12V\n\x0f\x62uffering_hints\x18\x03 \x01(\x0b\x32=.oak9.tython.aws.kinesisfirehose.DeliveryStreamBufferingHints\x12l\n\x1b\x63loud_watch_logging_options\x18\x04 \x01(\x0b\x32G.oak9.tython.aws.kinesisfirehose.DeliveryStreamCloudWatchLoggingOptions\x12\x1a\n\x12\x63ompression_format\x18\x05 \x01(\t\x12~\n$data_format_conversion_configuration\x18\x06 \x01(\x0b\x32P.oak9.tython.aws.kinesisfirehose.DeliveryStreamDataFormatConversionConfiguration\x12h\n\x18\x65ncryption_configuration\x18\x07 \x01(\x0b\x32\x46.oak9.tython.aws.kinesisfirehose.DeliveryStreamEncryptionConfiguration\x12\x1b\n\x13\x65rror_output_prefix\x18\x08 \x01(\t\x12\x0e\n\x06prefix\x18\t \x01(\t\x12h\n\x18processing_configuration\x18\n \x01(\x0b\x32\x46.oak9.tython.aws.kinesisfirehose.DeliveryStreamProcessingConfiguration\x12\x10\n\x08role_arn\x18\x0b \x01(\t\x12j\n\x17s3_backup_configuration\x18\x0c \x01(\x0b\x32I.oak9.tython.aws.kinesisfirehose.DeliveryStreamS3DestinationConfiguration\x12\x16\n\x0es3_backup_mode\x18\r \x01(\t\"\x97\x01\n.DeliveryStreamKinesisStreamSourceConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12kinesis_stream_arn\x18\x02 \x01(\t\x12\x10\n\x08role_arn\x18\x03 \x01(\t\"\x9f\x01\n\x19\x44\x65liveryStreamCopyCommand\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0c\x63opy_options\x18\x02 \x01(\t\x12\x1a\n\x12\x64\x61ta_table_columns\x18\x03 \x01(\t\x12\x17\n\x0f\x64\x61ta_table_name\x18\x04 \x01(\t\"z\n\"DeliveryStreamRedshiftRetryOptions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13\x64uration_in_seconds\x18\x02 \x01(\x05\"\xac\x06\n.DeliveryStreamRedshiftDestinationConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12l\n\x1b\x63loud_watch_logging_options\x18\x02 \x01(\x0b\x32G.oak9.tython.aws.kinesisfirehose.DeliveryStreamCloudWatchLoggingOptions\x12\x1c\n\x14\x63luster_j_db_c_u_r_l\x18\x03 \x01(\t\x12P\n\x0c\x63opy_command\x18\x04 \x01(\x0b\x32:.oak9.tython.aws.kinesisfirehose.DeliveryStreamCopyCommand\x12\x10\n\x08password\x18\x05 \x01(\t\x12h\n\x18processing_configuration\x18\x06 \x01(\x0b\x32\x46.oak9.tython.aws.kinesisfirehose.DeliveryStreamProcessingConfiguration\x12Z\n\rretry_options\x18\x07 \x01(\x0b\x32\x43.oak9.tython.aws.kinesisfirehose.DeliveryStreamRedshiftRetryOptions\x12\x10\n\x08role_arn\x18\x08 \x01(\t\x12j\n\x17s3_backup_configuration\x18\t \x01(\x0b\x32I.oak9.tython.aws.kinesisfirehose.DeliveryStreamS3DestinationConfiguration\x12\x16\n\x0es3_backup_mode\x18\n \x01(\t\x12\x63\n\x10s3_configuration\x18\x0b \x01(\x0b\x32I.oak9.tython.aws.kinesisfirehose.DeliveryStreamS3DestinationConfiguration\x12\x10\n\x08username\x18\x0c \x01(\t\"x\n DeliveryStreamSplunkRetryOptions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13\x64uration_in_seconds\x18\x02 \x01(\x05\"\x88\x05\n,DeliveryStreamSplunkDestinationConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12l\n\x1b\x63loud_watch_logging_options\x18\x02 \x01(\x0b\x32G.oak9.tython.aws.kinesisfirehose.DeliveryStreamCloudWatchLoggingOptions\x12,\n$hecacknowledgment_timeout_in_seconds\x18\x03 \x01(\x05\x12\x14\n\x0chec_endpoint\x18\x04 \x01(\t\x12\x19\n\x11hec_endpoint_type\x18\x05 \x01(\t\x12\x11\n\thec_token\x18\x06 \x01(\t\x12h\n\x18processing_configuration\x18\x07 \x01(\x0b\x32\x46.oak9.tython.aws.kinesisfirehose.DeliveryStreamProcessingConfiguration\x12X\n\rretry_options\x18\x08 \x01(\x0b\x32\x41.oak9.tython.aws.kinesisfirehose.DeliveryStreamSplunkRetryOptions\x12\x16\n\x0es3_backup_mode\x18\t \x01(\t\x12\x63\n\x10s3_configuration\x18\n \x01(\x0b\x32I.oak9.tython.aws.kinesisfirehose.DeliveryStreamS3DestinationConfiguration\"\x91\x01\n\'DeliveryStreamHttpEndpointConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x12\n\naccess_key\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\"\x95\x01\n)DeliveryStreamHttpEndpointCommonAttribute\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x61ttribute_name\x18\x02 \x01(\t\x12\x17\n\x0f\x61ttribute_value\x18\x03 \x01(\t\"\xea\x01\n.DeliveryStreamHttpEndpointRequestConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x63ontent_encoding\x18\x02 \x01(\t\x12\x65\n\x11\x63ommon_attributes\x18\x03 \x03(\x0b\x32J.oak9.tython.aws.kinesisfirehose.DeliveryStreamHttpEndpointCommonAttribute\"r\n\x1a\x44\x65liveryStreamRetryOptions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13\x64uration_in_seconds\x18\x02 \x01(\x05\"\xda\x06\n2DeliveryStreamHttpEndpointDestinationConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08role_arn\x18\x02 \x01(\t\x12h\n\x16\x65ndpoint_configuration\x18\x03 \x01(\x0b\x32H.oak9.tython.aws.kinesisfirehose.DeliveryStreamHttpEndpointConfiguration\x12n\n\x15request_configuration\x18\x04 \x01(\x0b\x32O.oak9.tython.aws.kinesisfirehose.DeliveryStreamHttpEndpointRequestConfiguration\x12V\n\x0f\x62uffering_hints\x18\x05 \x01(\x0b\x32=.oak9.tython.aws.kinesisfirehose.DeliveryStreamBufferingHints\x12l\n\x1b\x63loud_watch_logging_options\x18\x06 \x01(\x0b\x32G.oak9.tython.aws.kinesisfirehose.DeliveryStreamCloudWatchLoggingOptions\x12h\n\x18processing_configuration\x18\x07 \x01(\x0b\x32\x46.oak9.tython.aws.kinesisfirehose.DeliveryStreamProcessingConfiguration\x12R\n\rretry_options\x18\x08 \x01(\x0b\x32;.oak9.tython.aws.kinesisfirehose.DeliveryStreamRetryOptions\x12\x16\n\x0es3_backup_mode\x18\t \x01(\t\x12\x63\n\x10s3_configuration\x18\n \x01(\x0b\x32I.oak9.tython.aws.kinesisfirehose.DeliveryStreamS3DestinationConfiguration\"\xfc\x07\n\x0e\x44\x65liveryStream\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1c\n\x14\x64\x65livery_stream_name\x18\x02 \x01(\t\x12\x1c\n\x14\x64\x65livery_stream_type\x18\x03 \x01(\t\x12\x85\x01\n\'elasticsearch_destination_configuration\x18\x04 \x01(\x0b\x32T.oak9.tython.aws.kinesisfirehose.DeliveryStreamElasticsearchDestinationConfiguration\x12\x80\x01\n%extended_s3_destination_configuration\x18\x05 \x01(\x0b\x32Q.oak9.tython.aws.kinesisfirehose.DeliveryStreamExtendedS3DestinationConfiguration\x12|\n#kinesis_stream_source_configuration\x18\x06 \x01(\x0b\x32O.oak9.tython.aws.kinesisfirehose.DeliveryStreamKinesisStreamSourceConfiguration\x12{\n\"redshift_destination_configuration\x18\x07 \x01(\x0b\x32O.oak9.tython.aws.kinesisfirehose.DeliveryStreamRedshiftDestinationConfiguration\x12o\n\x1cs3_destination_configuration\x18\x08 \x01(\x0b\x32I.oak9.tython.aws.kinesisfirehose.DeliveryStreamS3DestinationConfiguration\x12w\n splunk_destination_configuration\x18\t \x01(\x0b\x32M.oak9.tython.aws.kinesisfirehose.DeliveryStreamSplunkDestinationConfiguration\x12\x84\x01\n\'http_endpoint_destination_configuration\x18\n \x01(\x0b\x32S.oak9.tython.aws.kinesisfirehose.DeliveryStreamHttpEndpointDestinationConfiguration\"[\n\x0fKinesisFirehose\x12H\n\x0f\x64\x65livery_stream\x18\x01 \x03(\x0b\x32/.oak9.tython.aws.kinesisfirehose.DeliveryStreamb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_kinesisfirehose_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DELIVERYSTREAMOPENXJSONSERDE_COLUMNTOJSONKEYMAPPINGSENTRY._options = None
  _DELIVERYSTREAMOPENXJSONSERDE_COLUMNTOJSONKEYMAPPINGSENTRY._serialized_options = b'8\001'
  _DELIVERYSTREAMELASTICSEARCHBUFFERINGHINTS._serialized_start=88
  _DELIVERYSTREAMELASTICSEARCHBUFFERINGHINTS._serialized_end=238
  _DELIVERYSTREAMCLOUDWATCHLOGGINGOPTIONS._serialized_start=241
  _DELIVERYSTREAMCLOUDWATCHLOGGINGOPTIONS._serialized_end=404
  _DELIVERYSTREAMPROCESSORPARAMETER._serialized_start=407
  _DELIVERYSTREAMPROCESSORPARAMETER._serialized_end=547
  _DELIVERYSTREAMPROCESSOR._serialized_start=550
  _DELIVERYSTREAMPROCESSOR._serialized_end=719
  _DELIVERYSTREAMPROCESSINGCONFIGURATION._serialized_start=722
  _DELIVERYSTREAMPROCESSINGCONFIGURATION._serialized_end=913
  _DELIVERYSTREAMELASTICSEARCHRETRYOPTIONS._serialized_start=915
  _DELIVERYSTREAMELASTICSEARCHRETRYOPTIONS._serialized_end=1042
  _DELIVERYSTREAMBUFFERINGHINTS._serialized_start=1045
  _DELIVERYSTREAMBUFFERINGHINTS._serialized_end=1182
  _DELIVERYSTREAMKMSENCRYPTIONCONFIG._serialized_start=1184
  _DELIVERYSTREAMKMSENCRYPTIONCONFIG._serialized_end=1301
  _DELIVERYSTREAMENCRYPTIONCONFIGURATION._serialized_start=1304
  _DELIVERYSTREAMENCRYPTIONCONFIGURATION._serialized_end=1529
  _DELIVERYSTREAMS3DESTINATIONCONFIGURATION._serialized_start=1532
  _DELIVERYSTREAMS3DESTINATIONCONFIGURATION._serialized_end=2046
  _DELIVERYSTREAMVPCCONFIGURATION._serialized_start=2049
  _DELIVERYSTREAMVPCCONFIGURATION._serialized_end=2204
  _DELIVERYSTREAMELASTICSEARCHDESTINATIONCONFIGURATION._serialized_start=2207
  _DELIVERYSTREAMELASTICSEARCHDESTINATIONCONFIGURATION._serialized_end=3082
  _DELIVERYSTREAMHIVEJSONSERDE._serialized_start=3084
  _DELIVERYSTREAMHIVEJSONSERDE._serialized_end=3197
  _DELIVERYSTREAMOPENXJSONSERDE._serialized_start=3200
  _DELIVERYSTREAMOPENXJSONSERDE._serialized_end=3556
  _DELIVERYSTREAMOPENXJSONSERDE_COLUMNTOJSONKEYMAPPINGSENTRY._serialized_start=3494
  _DELIVERYSTREAMOPENXJSONSERDE_COLUMNTOJSONKEYMAPPINGSENTRY._serialized_end=3556
  _DELIVERYSTREAMDESERIALIZER._serialized_start=3559
  _DELIVERYSTREAMDESERIALIZER._serialized_end=3823
  _DELIVERYSTREAMINPUTFORMATCONFIGURATION._serialized_start=3826
  _DELIVERYSTREAMINPUTFORMATCONFIGURATION._serialized_end=4006
  _DELIVERYSTREAMORCSERDE._serialized_start=4009
  _DELIVERYSTREAMORCSERDE._serialized_end=4378
  _DELIVERYSTREAMPARQUETSERDE._serialized_start=4381
  _DELIVERYSTREAMPARQUETSERDE._serialized_end=4628
  _DELIVERYSTREAMSERIALIZER._serialized_start=4631
  _DELIVERYSTREAMSERIALIZER._serialized_end=4876
  _DELIVERYSTREAMOUTPUTFORMATCONFIGURATION._serialized_start=4879
  _DELIVERYSTREAMOUTPUTFORMATCONFIGURATION._serialized_end=5056
  _DELIVERYSTREAMSCHEMACONFIGURATION._serialized_start=5059
  _DELIVERYSTREAMSCHEMACONFIGURATION._serialized_end=5268
  _DELIVERYSTREAMDATAFORMATCONVERSIONCONFIGURATION._serialized_start=5271
  _DELIVERYSTREAMDATAFORMATCONVERSIONCONFIGURATION._serialized_end=5712
  _DELIVERYSTREAMEXTENDEDS3DESTINATIONCONFIGURATION._serialized_start=5715
  _DELIVERYSTREAMEXTENDEDS3DESTINATIONCONFIGURATION._serialized_end=6603
  _DELIVERYSTREAMKINESISSTREAMSOURCECONFIGURATION._serialized_start=6606
  _DELIVERYSTREAMKINESISSTREAMSOURCECONFIGURATION._serialized_end=6757
  _DELIVERYSTREAMCOPYCOMMAND._serialized_start=6760
  _DELIVERYSTREAMCOPYCOMMAND._serialized_end=6919
  _DELIVERYSTREAMREDSHIFTRETRYOPTIONS._serialized_start=6921
  _DELIVERYSTREAMREDSHIFTRETRYOPTIONS._serialized_end=7043
  _DELIVERYSTREAMREDSHIFTDESTINATIONCONFIGURATION._serialized_start=7046
  _DELIVERYSTREAMREDSHIFTDESTINATIONCONFIGURATION._serialized_end=7858
  _DELIVERYSTREAMSPLUNKRETRYOPTIONS._serialized_start=7860
  _DELIVERYSTREAMSPLUNKRETRYOPTIONS._serialized_end=7980
  _DELIVERYSTREAMSPLUNKDESTINATIONCONFIGURATION._serialized_start=7983
  _DELIVERYSTREAMSPLUNKDESTINATIONCONFIGURATION._serialized_end=8631
  _DELIVERYSTREAMHTTPENDPOINTCONFIGURATION._serialized_start=8634
  _DELIVERYSTREAMHTTPENDPOINTCONFIGURATION._serialized_end=8779
  _DELIVERYSTREAMHTTPENDPOINTCOMMONATTRIBUTE._serialized_start=8782
  _DELIVERYSTREAMHTTPENDPOINTCOMMONATTRIBUTE._serialized_end=8931
  _DELIVERYSTREAMHTTPENDPOINTREQUESTCONFIGURATION._serialized_start=8934
  _DELIVERYSTREAMHTTPENDPOINTREQUESTCONFIGURATION._serialized_end=9168
  _DELIVERYSTREAMRETRYOPTIONS._serialized_start=9170
  _DELIVERYSTREAMRETRYOPTIONS._serialized_end=9284
  _DELIVERYSTREAMHTTPENDPOINTDESTINATIONCONFIGURATION._serialized_start=9287
  _DELIVERYSTREAMHTTPENDPOINTDESTINATIONCONFIGURATION._serialized_end=10145
  _DELIVERYSTREAM._serialized_start=10148
  _DELIVERYSTREAM._serialized_end=11168
  _KINESISFIREHOSE._serialized_start=11170
  _KINESISFIREHOSE._serialized_end=11261
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ServerStorageVersion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_SERVER_ID_FIELD_NUMBER: builtins.int
    DECODABLE_VERSIONS_FIELD_NUMBER: builtins.int
    ENCODING_VERSION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_server_id: builtins.str
    @property
    def decodable_versions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    encoding_version: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_server_id: builtins.str = ...,
        decodable_versions: collections.abc.Iterable[builtins.str] | None = ...,
        encoding_version: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_server_id", b"api_server_id", "decodable_versions", b"decodable_versions", "encoding_version", b"encoding_version", "resource_info", b"resource_info"]) -> None: ...

global___ServerStorageVersion = ServerStorageVersion

@typing_extensions.final
class StorageVersion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def spec(self) -> global___StorageVersionSpec: ...
    @property
    def status(self) -> global___StorageVersionStatus: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        spec: global___StorageVersionSpec | None = ...,
        status: global___StorageVersionStatus | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> None: ...

global___StorageVersion = StorageVersion

@typing_extensions.final
class StorageVersionCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LAST_TRANSITION_TIME_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    OBSERVED_GENERATION_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def last_transition_time(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time: ...
    message: builtins.str
    observed_generation: builtins.int
    reason: builtins.str
    status: builtins.str
    type: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        last_transition_time: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time | None = ...,
        message: builtins.str = ...,
        observed_generation: builtins.int = ...,
        reason: builtins.str = ...,
        status: builtins.str = ...,
        type: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["last_transition_time", b"last_transition_time", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["last_transition_time", b"last_transition_time", "message", b"message", "observed_generation", b"observed_generation", "reason", b"reason", "resource_info", b"resource_info", "status", b"status", "type", b"type"]) -> None: ...

global___StorageVersionCondition = StorageVersionCondition

@typing_extensions.final
class StorageVersionList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StorageVersion]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___StorageVersion] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___StorageVersionList = StorageVersionList

@typing_extensions.final
class StorageVersionSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> None: ...

global___StorageVersionSpec = StorageVersionSpec

@typing_extensions.final
class StorageVersionStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMON_ENCODING_VERSION_FIELD_NUMBER: builtins.int
    CONDITIONS_FIELD_NUMBER: builtins.int
    STORAGE_VERSIONS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    common_encoding_version: builtins.str
    @property
    def conditions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StorageVersionCondition]: ...
    @property
    def storage_versions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServerStorageVersion]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        common_encoding_version: builtins.str = ...,
        conditions: collections.abc.Iterable[global___StorageVersionCondition] | None = ...,
        storage_versions: collections.abc.Iterable[global___ServerStorageVersion] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["common_encoding_version", b"common_encoding_version", "conditions", b"conditions", "resource_info", b"resource_info", "storage_versions", b"storage_versions"]) -> None: ...

global___StorageVersionStatus = StorageVersionStatus



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_autoscalingplans.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x61ws/aws_autoscalingplans.proto\x12 oak9.tython.aws.autoscalingplans\x1a\x13shared/shared.proto\"l\n\x14ScalingPlanTagFilter\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06values\x18\x02 \x03(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\"\xc7\x01\n\x1cScalingPlanApplicationSource\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12!\n\x19\x63loud_formation_stack_arn\x18\x02 \x01(\t\x12K\n\x0btag_filters\x18\x03 \x03(\x0b\x32\x36.oak9.tython.aws.autoscalingplans.ScalingPlanTagFilter\"\xaa\x01\n/ScalingPlanPredefinedScalingMetricSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0eresource_label\x18\x02 \x01(\t\x12&\n\x1epredefined_scaling_metric_type\x18\x03 \x01(\t\"r\n\x1aScalingPlanMetricDimension\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05value\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"\x85\x02\n/ScalingPlanCustomizedScalingMetricSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bmetric_name\x18\x02 \x01(\t\x12\x11\n\tstatistic\x18\x03 \x01(\t\x12P\n\ndimensions\x18\x04 \x03(\x0b\x32<.oak9.tython.aws.autoscalingplans.ScalingPlanMetricDimension\x12\x0c\n\x04unit\x18\x05 \x01(\t\x12\x11\n\tnamespace\x18\x06 \x01(\t\"\xf5\x03\n&ScalingPlanTargetTrackingConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12scale_out_cooldown\x18\x02 \x01(\x05\x12\x14\n\x0ctarget_value\x18\x03 \x01(\x01\x12\x82\x01\n\'predefined_scaling_metric_specification\x18\x04 \x01(\x0b\x32Q.oak9.tython.aws.autoscalingplans.ScalingPlanPredefinedScalingMetricSpecification\x12\x18\n\x10\x64isable_scale_in\x18\x05 \x01(\x08\x12\x19\n\x11scale_in_cooldown\x18\x06 \x01(\x05\x12!\n\x19\x65stimated_instance_warmup\x18\x07 \x01(\x05\x12\x82\x01\n\'customized_scaling_metric_specification\x18\x08 \x01(\x0b\x32Q.oak9.tython.aws.autoscalingplans.ScalingPlanCustomizedScalingMetricSpecification\"\x82\x02\n,ScalingPlanCustomizedLoadMetricSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bmetric_name\x18\x02 \x01(\t\x12\x11\n\tstatistic\x18\x03 \x01(\t\x12P\n\ndimensions\x18\x04 \x03(\x0b\x32<.oak9.tython.aws.autoscalingplans.ScalingPlanMetricDimension\x12\x0c\n\x04unit\x18\x05 \x01(\t\x12\x11\n\tnamespace\x18\x06 \x01(\t\"\xa4\x01\n,ScalingPlanPredefinedLoadMetricSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12#\n\x1bpredefined_load_metric_type\x18\x02 \x01(\t\x12\x16\n\x0eresource_label\x18\x03 \x01(\t\"\xb0\x06\n\x1dScalingPlanScalingInstruction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1f\n\x17\x64isable_dynamic_scaling\x18\x02 \x01(\x08\x12\x19\n\x11service_namespace\x18\x03 \x01(\t\x12\x30\n(predictive_scaling_max_capacity_behavior\x18\x04 \x01(\t\x12\x1a\n\x12scalable_dimension\x18\x05 \x01(\t\x12&\n\x1escaling_policy_update_behavior\x18\x06 \x01(\t\x12\x14\n\x0cmin_capacity\x18\x07 \x01(\x05\x12p\n\x1etarget_tracking_configurations\x18\x08 \x03(\x0b\x32H.oak9.tython.aws.autoscalingplans.ScalingPlanTargetTrackingConfiguration\x12.\n&predictive_scaling_max_capacity_buffer\x18\t \x01(\x05\x12|\n$customized_load_metric_specification\x18\n \x01(\x0b\x32N.oak9.tython.aws.autoscalingplans.ScalingPlanCustomizedLoadMetricSpecification\x12|\n$predefined_load_metric_specification\x18\x0b \x01(\x0b\x32N.oak9.tython.aws.autoscalingplans.ScalingPlanPredefinedLoadMetricSpecification\x12\x13\n\x0bresource_id\x18\x0c \x01(\t\x12$\n\x1cscheduled_action_buffer_time\x18\r \x01(\x05\x12\x14\n\x0cmax_capacity\x18\x0e \x01(\x05\x12\x1f\n\x17predictive_scaling_mode\x18\x0f \x01(\t\"\x81\x02\n\x0bScalingPlan\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12Z\n\x12\x61pplication_source\x18\x02 \x01(\x0b\x32>.oak9.tython.aws.autoscalingplans.ScalingPlanApplicationSource\x12]\n\x14scaling_instructions\x18\x03 \x03(\x0b\x32?.oak9.tython.aws.autoscalingplans.ScalingPlanScalingInstruction\"W\n\x10\x41utoScalingPlans\x12\x43\n\x0cscaling_plan\x18\x01 \x03(\x0b\x32-.oak9.tython.aws.autoscalingplans.ScalingPlanb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_autoscalingplans_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SCALINGPLANTAGFILTER._serialized_start=89
  _SCALINGPLANTAGFILTER._serialized_end=197
  _SCALINGPLANAPPLICATIONSOURCE._serialized_start=200
  _SCALINGPLANAPPLICATIONSOURCE._serialized_end=399
  _SCALINGPLANPREDEFINEDSCALINGMETRICSPECIFICATION._serialized_start=402
  _SCALINGPLANPREDEFINEDSCALINGMETRICSPECIFICATION._serialized_end=572
  _SCALINGPLANMETRICDIMENSION._serialized_start=574
  _SCALINGPLANMETRICDIMENSION._serialized_end=688
  _SCALINGPLANCUSTOMIZEDSCALINGMETRICSPECIFICATION._serialized_start=691
  _SCALINGPLANCUSTOMIZEDSCALINGMETRICSPECIFICATION._serialized_end=952
  _SCALINGPLANTARGETTRACKINGCONFIGURATION._serialized_start=955
  _SCALINGPLANTARGETTRACKINGCONFIGURATION._serialized_end=1456
  _SCALINGPLANCUSTOMIZEDLOADMETRICSPECIFICATION._serialized_start=1459
  _SCALINGPLANCUSTOMIZEDLOADMETRICSPECIFICATION._serialized_end=1717
  _SCALINGPLANPREDEFINEDLOADMETRICSPECIFICATION._serialized_start=1720
  _SCALINGPLANPREDEFINEDLOADMETRICSPECIFICATION._serialized_end=1884
  _SCALINGPLANSCALINGINSTRUCTION._serialized_start=1887
  _SCALINGPLANSCALINGINSTRUCTION._serialized_end=2703
  _SCALINGPLAN._serialized_start=2706
  _SCALINGPLAN._serialized_end=2963
  _AUTOSCALINGPLANS._serialized_start=2965
  _AUTOSCALINGPLANS._serialized_end=3052
# @@protoc_insertion_point(module_scope)
